#!/bin/sh
# -----------------------------------------------------------------------------
# This part of code was taken from Start and Stop scripts for the CATALINA Server. 
# See Catalina Licence or obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# 
# -----------------------------------------------------------------------------

# resolve links - $0 may be a softlink
PRG="$0"
if [ ! -h "$PRG" ]; then
  PRGDIR="$( cd "$( dirname "$0" )" && pwd )"
else
  while [ -h "$PRG" ] ; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '.*-> \(.*\)$'`
    if expr "$link" : '/.*' > /dev/null; then
      PRG="$link"
    else
      PRG=`dirname "$PRG"`/"$link"
    fi
  done
  PRGDIR=`dirname "$PRG"`
fi
# from here See iceScrum Licence
# set config file and export it.
CONF="$PRGDIR/conf/config.properties"
export icescrum_config_location=$CONF

CATALINA_HOME="$PRGDIR/server"
EXECUTABLE="$CATALINA_HOME/bin/catalina.sh"
# set the iceScrum pid file :
ICE_PID="$CATALINA_HOME/work/iceScrum.pid"

get_pid() {
#  if [[ $(ps a | grep -c -e "/bin/java.*$CATALINA_HOME.*") != 1 ]]; then
    set $(ps a | grep -e "/bin/java.*$CATALINA_HOME.*")
    echo $1
#  fi
}
PID=$(get_pid)
# Check that target executable exists
if [ ! -x "$EXECUTABLE" ]; then
  echo "Cannot find $EXECUTABLE"
  echo "This file is needed to run this program"
  exit 1
fi

start() {
  if [[ -f "$ICE_PID" ]]; then
    echo -n "iceScrum server already started with PID $PID"
    echo
  else
    echo -n "Starting iceScrum server with configuration file : $icescrum_config_location"
    echo
    `exec "$EXECUTABLE" $@ &>/dev/null`
    get_pid>$ICE_PID
  fi
  return $?
}

# 
stop() {  
  if [[ -f $ICE_PID ]]; then
    PID1=$(cat $ICE_PID)
    echo -n "Stopping iceScrum server $@"
  	echo
  	`exec "$EXECUTABLE" $@ &>/dev/null`
    if [[ $(get_pid) == $PID1 ]]; then
      echo -n "Warning: Catalina don't stop -> Killing server process $PID"
      echo
      kill $PID &>/dev/null
    fi
    rm -f $ICE_PID
  else
    echo -n "iceScrum server is not running"
  	echo
  fi
  return $?
}
status() {
  if [[ -f $ICE_PID ]]; then
    echo -n "iceScrum server is running"
  else
    echo -n "iceScrum server is not running"
  fi
  	echo

}
other() {
  echo -n "Executing Catalina server with options : '$@' "
	echo
  exec "$EXECUTABLE" "$@"
  return $?
}

case "$1" in
  start)
	start $@
	;;
  stop)
	stop $@
	;;
  restart)
	stop stop
  sleep 2
	start start
	;;
  status)
  status
  ;;
  *)
	other $@
esac
exit $?

